@@ -135,9 +135,13 @@ class ExecException(Exception):
 
 # copy from surf expression.py
 probeReserveVars = ('common_pid', 'common_preempt_count', 'common_flags', 'common_type')
-archRegd = {'x86_64': ('di', 'si', 'dx', 'cx', 'r8', 'r9', 'ax', 'bx'),
-            'x86': ('di', 'si', 'dx', 'cx', 'ax', 'bx'),
-            'aarch64': ('x0', 'x1', 'x2', 'x3', 'x4', 'x5', 'x6', 'x7'),}
+archRegd = {'x86_64': ('di', 'si', 'dx', 'cx', 'r8', 'r9', 'ax', 'bx',
+                       'sp', 'bp', 'r10', 'r11', 'r12', 'r13', 'r14', 'r15',),
+            'x86': ('di', 'si', 'dx', 'cx'),
+            'aarch64': ('x0', 'x1', 'x2', 'x3', 'x4', 'x5', 'x6', 'x7', 'x8', 'x9',
+                        'x10', 'x11', 'x12', 'x13', 'x14', 'x15', 'x16', 'x17', 'x18', 'x19',
+                        'x20', 'x21', 'x22', 'x23', 'x24', 'x25', 'x26', 'x27', 'x28', 'x29',
+                        'x30', 'x31'),}
 
 def maxNameString(cells, t):
     rs = cells[0][t]
@@ -458,19 +462,15 @@ class ClbcClient(object):
         self._fastOff = False
 
     def _getArchitecture(self, c):
-        lines = c.cmd('lscpu').split('\n')
-        for line in lines:
-            if line.startswith("Architecture"):
-                arch = line.split(":", 1)[1].strip()
-                if arch.startswith("arm"):
-                    return "arm"
-                return arch
-        return "Unkown"
+        return c.cmd('uname -m')
 
     def _setupSocket(self):
         addr = (self._server, LBC_COMPILE_PORT)
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        s.connect(addr)
+        try:
+            s.connect(addr)
+        except socket.gaierror:
+            raise DbException("cannot connect remote server:%s" % self._server)
         return s
 
     @staticmethod
@@ -1265,8 +1265,8 @@ class surftrace(ftrace):
         if res['log'] != "ok.":
             raise DbException('db get %s return %s' % (func, res['log']))
         return res
-    
-    def __getExprArgi(self, e): 
+
+    def __getExprArgi(self, e, inFlag):
         # expression: a=@(struct iphdr *)l4%1->saddr uesrs=!(struct task_struct *)%0->mm->mm_users
         # e is already checked at self.__checkBegExpr
         var, expr = e.split("=", 1)
@@ -1284,7 +1284,10 @@ class surftrace(ftrace):
             else:
                 argi = regIndex(reg, self._arch)
             if types == '':
-                argt = self._func['args'][argi]
+                if inFlag:
+                    argt = 'u64'
+                else:
+                    argt = self._func['args'][argi]
             else:
                 argt = types
             regArch = transReg(argi, self._arch)
@@ -1506,12 +1509,12 @@ class surftrace(ftrace):
             i += 2
         self._fxprAddSuffix(lastCell)
         return lastCell
-            
-    def _checkExpr(self, e):
+
+    def _checkExpr(self, e, inFlag):
         self.__checkBegExpr(e)
         self.__checkFormat(e)
 
-        showType, reg, argt, xpr = self.__getExprArgi(e)
+        showType, reg, argt, xpr = self.__getExprArgi(e, inFlag)
 
         cells = self._splitPr(argt, xpr)
         res = self._cellCheck(cells, reg)
@@ -1549,22 +1552,24 @@ class surftrace(ftrace):
         name = "f%d" % i
         cmd = "%s:f%d " % (res['type'], i)
         symbol = res['symbol']
+        inFlag = False
 
         func = symbol
         if "+" in func:
             func = func.split("+", 1)[0]
+            inFlag = True
         try:
             self._func = self._getVmFunc(func)['res'][0]
         except (TypeError, KeyError, IndexError):
             raise DbException("no %s debuginfo  in file." % symbol)
         cmd += self.__checkSymbol(symbol)
-        
+
         vars = []
         for expr in splitExpr(res['args']):
             if expr == "":
                 continue
             self._res = res
-            self._checkExpr(expr)
+            self._checkExpr(expr, inFlag)
             var, _ = expr.split("=", 1)
             if var in vars:
                 raise ExprException("var %s is already used at previous expression" % var)
